/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QABSTRACTMEDIASERVICE_H
#define QABSTRACTMEDIASERVICE_H

#include <QtMultimedia/qtmultimediadefs.h>
#include <QtCore/qobject.h>
#include <QtCore/qstringlist.h>

#include <QtMultimedia/qmediacontrol.h>

QT_BEGIN_NAMESPACE


class QMediaServicePrivate;
class Q_MULTIMEDIA_EXPORT QMediaService : public QObject
{
    Q_OBJECT

public:
    ~QMediaService();

    virtual QMediaControl* requestControl(const char *name) = 0;

#ifndef QT_NO_MEMBER_TEMPLATES
    template <typename T> inline T requestControl() {
        if (QMediaControl *control = requestControl(qmediacontrol_iid<T>())) {
            if (T typedControl = qobject_cast<T>(control))
                return typedControl;
            releaseControl(control);
        }
        return 0;
    }
#endif

    virtual void releaseControl(QMediaControl *control) = 0;

protected:
    QMediaService(QObject* parent);
    QMediaService(QMediaServicePrivate &dd, QObject *parent);

    QMediaServicePrivate *d_ptr;

private:
    Q_DECLARE_PRIVATE(QMediaService)
};

QT_END_NAMESPACE


#endif  // QABSTRACTMEDIASERVICE_H

